You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tinkerpop.apache.org by sp...@apache.org on 2015/02/12 14:02:30 UTC

[64/77] incubator-tinkerpop git commit: replaced namespace com.tinkerpop with org.apache.tinkerpop

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/GraphStrategy.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/GraphStrategy.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/GraphStrategy.java
index ba9d22c..adf6f06 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/GraphStrategy.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/GraphStrategy.java
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
+package org.apache.tinkerpop.gremlin.structure.strategy;
 
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.util.function.TriFunction;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.util.function.TriFunction;
 
 import java.util.Iterator;
 import java.util.Map;
@@ -44,8 +44,8 @@ import java.util.function.UnaryOperator;
  * represents some injection point for new logic in the Gremlin Structure API.  A method always accepts a
  * {@link StrategyContext} which contains the context of the call being made and will have
  * a different {@link StrategyContext#getCurrent()} object depending on that context (e.g the
- * {@link com.tinkerpop.gremlin.structure.Vertex#addEdge(String, com.tinkerpop.gremlin.structure.Vertex, Object...)} method will send the instance of
- * the {@link com.tinkerpop.gremlin.structure.Vertex} that was the object of that method call).
+ * {@link org.apache.tinkerpop.gremlin.structure.Vertex#addEdge(String, org.apache.tinkerpop.gremlin.structure.Vertex, Object...)} method will send the instance of
+ * the {@link org.apache.tinkerpop.gremlin.structure.Vertex} that was the object of that method call).
  * <p/>
  * A method will always return a {@link java.util.function.UnaryOperator} where the argument and return value to it is a function with
  * the same signature as the calling method where the strategy logic is being injected.  The argument passed in to
@@ -66,12 +66,12 @@ import java.util.function.UnaryOperator;
 public interface GraphStrategy {
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph.Iterators#vertexIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph.Iterators#vertexIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Graph.Iterators#vertexIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph.Iterators#vertexIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Function<Object[], Iterator<Vertex>>> getGraphIteratorsVertexIteratorStrategy(final StrategyContext<StrategyGraph> ctx, final GraphStrategy composingStrategy) {
@@ -79,12 +79,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph.Iterators#edgeIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph.Iterators#edgeIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Graph.Iterators#edgeIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph.Iterators#edgeIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Function<Object[], Iterator<Edge>>> getGraphIteratorsEdgeIteratorStrategy(final StrategyContext<StrategyGraph> ctx, final GraphStrategy composingStrategy) {
@@ -92,12 +92,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph.Variables#keys()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#keys()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Graph.Variables#keys()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#keys()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Set<String>>> getVariableKeysStrategy(final StrategyContext<StrategyVariables> ctx, final GraphStrategy composingStrategy) {
@@ -105,12 +105,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph.Variables#asMap()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#asMap()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Graph.Variables#asMap()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#asMap()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Map<String, Object>>> getVariableAsMapStrategy(final StrategyContext<StrategyVariables> ctx, final GraphStrategy composingStrategy) {
@@ -118,11 +118,11 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph.Variables#get(String)}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#get(String)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
-     * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with {@link com.tinkerpop.gremlin.structure.Graph.Variables#get(String)} signature
+     * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#get(String)} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default <R> UnaryOperator<Function<String, Optional<R>>> getVariableGetStrategy(final StrategyContext<StrategyVariables> ctx, final GraphStrategy composingStrategy) {
@@ -130,11 +130,11 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.BiConsumer} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph.Variables#set(String, Object)}.
+     * Construct a {@link java.util.function.BiConsumer} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#set(String, Object)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
-     * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.BiConsumer} with {@link com.tinkerpop.gremlin.structure.Graph.Variables#set(String, Object)} signature
+     * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.BiConsumer} with {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#set(String, Object)} signature
      * and returns an enhanced strategy {@link java.util.function.BiConsumer} with the same signature
      */
     public default UnaryOperator<BiConsumer<String, Object>> getVariableSetStrategy(final StrategyContext<StrategyVariables> ctx, final GraphStrategy composingStrategy) {
@@ -142,11 +142,11 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Consumer} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph.Variables#remove(String)}.
+     * Construct a {@link java.util.function.Consumer} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#remove(String)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
-     * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Consumer} with {@link com.tinkerpop.gremlin.structure.Graph.Variables#remove(String)} signature
+     * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Consumer} with {@link org.apache.tinkerpop.gremlin.structure.Graph.Variables#remove(String)} signature
      * and returns an enhanced strategy {@link java.util.function.BiConsumer} with the same signature
      */
     public default UnaryOperator<Consumer<String>> getVariableRemoveStrategy(final StrategyContext<StrategyVariables> ctx, final GraphStrategy composingStrategy) {
@@ -154,11 +154,11 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph#addVertex(Object...)}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph#addVertex(Object...)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
-     * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with {@link com.tinkerpop.gremlin.structure.Graph#addVertex(Object...)} signature
+     * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with {@link org.apache.tinkerpop.gremlin.structure.Graph#addVertex(Object...)} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default UnaryOperator<Function<Object[], Vertex>> getAddVertexStrategy(final StrategyContext<StrategyGraph> ctx, final GraphStrategy composingStrategy) {
@@ -166,13 +166,13 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link com.tinkerpop.gremlin.util.function.TriFunction} that enhances the features of
-     * {@link com.tinkerpop.gremlin.structure.Vertex#addEdge(String, com.tinkerpop.gremlin.structure.Vertex, Object...)}.
+     * Construct a {@link org.apache.tinkerpop.gremlin.util.function.TriFunction} that enhances the features of
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#addEdge(String, org.apache.tinkerpop.gremlin.structure.Vertex, Object...)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
-     * @return a {@link java.util.function.Function} that accepts a {@link com.tinkerpop.gremlin.util.function.TriFunction} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex#addEdge(String, com.tinkerpop.gremlin.structure.Vertex, Object...)} signature
+     * @return a {@link java.util.function.Function} that accepts a {@link org.apache.tinkerpop.gremlin.util.function.TriFunction} with
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#addEdge(String, org.apache.tinkerpop.gremlin.structure.Vertex, Object...)} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default UnaryOperator<TriFunction<String, Vertex, Object[], Edge>> getAddEdgeStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -180,12 +180,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge#remove()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge#remove()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Edge#remove()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge#remove()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Void>> getRemoveEdgeStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -193,12 +193,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex#remove()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex#remove()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex#remove()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#remove()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Void>> getRemoveVertexStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -206,12 +206,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Property#remove()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Property#remove()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Property#remove()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Property#remove()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<Void>> getRemovePropertyStrategy(final StrategyContext<StrategyProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -219,12 +219,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty#remove()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#remove()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty#remove()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#remove()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<Void>> getRemoveVertexPropertyStrategy(final StrategyContext<StrategyVertexProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -232,12 +232,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex#property(String)}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex#property(String)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex#property(String)} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#property(String)} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default <V> UnaryOperator<Function<String, VertexProperty<V>>> getVertexGetPropertyStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -245,12 +245,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex#keys()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex#keys()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex#keys()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#keys()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Set<String>>> getVertexKeysStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -258,12 +258,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex#label()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex#label()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex#label()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#label()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<String>> getVertexLabelStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -271,12 +271,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.BiFunction} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex#property(String, Object)}.
+     * Construct a {@link java.util.function.BiFunction} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex#property(String, Object)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.BiFunction} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex#property(String, Object)} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#property(String, Object)} signature
      * and returns an enhanced strategy {@link java.util.function.BiFunction} with the same signature
      */
     public default <V> UnaryOperator<BiFunction<String, V, VertexProperty<V>>> getVertexPropertyStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -284,12 +284,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Element.Iterators#propertyIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Element.Iterators#propertyIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Element.Iterators#propertyIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Element.Iterators#propertyIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Function<String[], Iterator<VertexProperty<V>>>> getVertexIteratorsPropertyIteratorStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -297,12 +297,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link TriFunction} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex.Iterators#vertexIterator}.
+     * Construct a {@link TriFunction} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex.Iterators#vertexIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link BiFunction} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex.Iterators#vertexIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex.Iterators#vertexIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<BiFunction<Direction, String[], Iterator<Vertex>>> getVertexIteratorsVertexIteratorStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -310,12 +310,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link TriFunction} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex.Iterators#edgeIterator}.
+     * Construct a {@link TriFunction} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex.Iterators#edgeIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link BiFunction} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex.Iterators#edgeIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex.Iterators#edgeIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<BiFunction<Direction, String[], Iterator<Edge>>> getVertexIteratorsEdgeIteratorStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -323,12 +323,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex.Iterators#valueIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex.Iterators#valueIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex.Iterators#valueIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex.Iterators#valueIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Function<String[], Iterator<V>>> getVertexIteratorsValueIteratorStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -336,12 +336,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex#id()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex#id()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex#id()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#id()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Object>> getVertexIdStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -349,14 +349,14 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Vertex#graph()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Vertex#graph()}.
      * Note that in this case, the {@link Graph} is {@link StrategyGraph} and this would be the expected
      * type to pass back out.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Vertex#graph()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Vertex#graph()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Graph>> getVertexGraphStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -364,12 +364,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Element#value(String)}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Element#value(String)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Element#value(String)} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Element#value(String)} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default <V> UnaryOperator<Function<String, V>> getVertexValueStrategy(final StrategyContext<StrategyVertex> ctx, final GraphStrategy composingStrategy) {
@@ -377,12 +377,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge#property(String)}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge#property(String)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Edge#property(String)} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge#property(String)} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default <V> UnaryOperator<Function<String, Property<V>>> getEdgeGetPropertyStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -390,12 +390,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge.Iterators#vertexIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge.Iterators#vertexIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Edge.Iterators#vertexIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge.Iterators#vertexIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Function<Direction, Iterator<Vertex>>> getEdgeIteratorsVertexIteratorStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -403,12 +403,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge.Iterators#valueIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge.Iterators#valueIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Edge.Iterators#valueIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge.Iterators#valueIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Function<String[], Iterator<V>>> getEdgeIteratorsValueIteratorStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -416,12 +416,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge.Iterators#propertyIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge.Iterators#propertyIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Edge.Iterators#propertyIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge.Iterators#propertyIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Function<String[], Iterator<Property<V>>>> getEdgeIteratorsPropertyIteratorStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -429,12 +429,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge#keys()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge#keys()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Edge#keys()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge#keys()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Set<String>>> getEdgeKeysStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -442,12 +442,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.BiFunction} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge#property(String, Object)}.
+     * Construct a {@link java.util.function.BiFunction} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge#property(String, Object)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.BiFunction} with
-     * {@link com.tinkerpop.gremlin.structure.Edge#property(String, Object)} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge#property(String, Object)} signature
      * and returns an enhanced strategy {@link java.util.function.BiFunction} with the same signature
      */
     public default <V> UnaryOperator<BiFunction<String, V, Property<V>>> getEdgePropertyStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -455,12 +455,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge#value(String)}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge#value(String)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Element#value(String)} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Element#value(String)} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default <V> UnaryOperator<Function<String, V>> getEdgeValueStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -468,12 +468,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge#id()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge#id()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Edge#id()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge#id()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Object>> getEdgeIdStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -481,14 +481,14 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge#graph()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge#graph()}.
      * Note that in this case, the {@link Graph} is {@link StrategyGraph} and this would be the expected
      * type to pass back out.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Edge#graph()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge#graph()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Graph>> getEdgeGraphStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -496,12 +496,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Edge#label()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Edge#label()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Edge#label()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Edge#label()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<String>> getEdgeLabelStrategy(final StrategyContext<StrategyEdge> ctx, final GraphStrategy composingStrategy) {
@@ -509,12 +509,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty#id()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#id()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty#id()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#id()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<Object>> getVertexPropertyIdStrategy(final StrategyContext<StrategyVertexProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -522,12 +522,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty#value()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#value()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Supplier} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty#value()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#value()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<V>> getVertexPropertyValueStrategy(final StrategyContext<StrategyVertexProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -535,12 +535,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Property#key()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Property#key()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Supplier} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Property#key()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Property#key()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<String>> getVertexPropertyKeyStrategy(final StrategyContext<StrategyVertexProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -548,12 +548,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty.Iterators#propertyIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty.Iterators#propertyIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty.Iterators#propertyIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty.Iterators#propertyIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V, U> UnaryOperator<Function<String[], Iterator<Property<V>>>> getVertexPropertyIteratorsPropertyIteratorStrategy(final StrategyContext<StrategyVertexProperty<U>> ctx, final GraphStrategy composingStrategy) {
@@ -561,12 +561,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty.Iterators#valueIterator}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty.Iterators#valueIterator}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty.Iterators#valueIterator} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty.Iterators#valueIterator} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V, U> UnaryOperator<Function<String[], Iterator<V>>> getVertexPropertyIteratorsValueIteratorStrategy(final StrategyContext<StrategyVertexProperty<U>> ctx, final GraphStrategy composingStrategy) {
@@ -574,12 +574,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.BiFunction} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty#property(String, Object)}.
+     * Construct a {@link java.util.function.BiFunction} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#property(String, Object)}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.BiFunction} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty#property(String, Object)} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#property(String, Object)} signature
      * and returns an enhanced strategy {@link java.util.function.BiFunction} with the same signature
      */
     public default <V, U> UnaryOperator<BiFunction<String, V, Property<V>>> getVertexPropertyPropertyStrategy(final StrategyContext<StrategyVertexProperty<U>> ctx, final GraphStrategy composingStrategy) {
@@ -587,14 +587,14 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty#graph()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#graph()}.
      * Note that in this case, the {@link Graph} is {@link StrategyGraph} and this would be the expected
      * type to pass back out.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty#graph()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#graph()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<Graph>> getVertexPropertyGraphStrategy(final StrategyContext<StrategyVertexProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -602,12 +602,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty#label()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#label()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty#label()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#label()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<String>> getVertexPropertyLabelStrategy(final StrategyContext<StrategyVertexProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -615,12 +615,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty#keys()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#keys()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty#keys()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#keys()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<Set<String>>> getVertexPropertyKeysStrategy(final StrategyContext<StrategyVertexProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -628,12 +628,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.VertexProperty#element}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#element}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.VertexProperty#element} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.VertexProperty#element} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<Vertex>> getVertexPropertyGetElementStrategy(final StrategyContext<StrategyVertexProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -641,12 +641,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph#close()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph#close()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Supplier} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Graph#close()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph#close()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default UnaryOperator<Supplier<Void>> getGraphCloseStrategy(final StrategyContext<StrategyGraph> ctx, final GraphStrategy composingStrategy) {
@@ -654,12 +654,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph#V}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph#V}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Graph#V} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph#V} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default UnaryOperator<Function<Object[], GraphTraversal<Vertex, Vertex>>> getGraphVStrategy(final StrategyContext<StrategyGraph> ctx, final GraphStrategy composingStrategy) {
@@ -667,12 +667,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Function} that enhances the features of {@link com.tinkerpop.gremlin.structure.Graph#E}.
+     * Construct a {@link java.util.function.Function} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Graph#E}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Function} that accepts a {@link java.util.function.Function} with
-     * {@link com.tinkerpop.gremlin.structure.Graph#E} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph#E} signature
      * and returns an enhanced strategy {@link java.util.function.Function} with the same signature
      */
     public default UnaryOperator<Function<Object[], GraphTraversal<Edge, Edge>>> getGraphEStrategy(final StrategyContext<StrategyGraph> ctx, final GraphStrategy composingStrategy) {
@@ -680,12 +680,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Property#value()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Property#value()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Supplier} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Property#value()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Property#value()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<V>> getPropertyValueStrategy(final StrategyContext<StrategyProperty<V>> ctx, final GraphStrategy composingStrategy) {
@@ -693,12 +693,12 @@ public interface GraphStrategy {
     }
 
     /**
-     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link com.tinkerpop.gremlin.structure.Property#key()}.
+     * Construct a {@link java.util.function.Supplier} that enhances the features of {@link org.apache.tinkerpop.gremlin.structure.Property#key()}.
      *
      * @param ctx               the context within which this strategy function is called
      * @param composingStrategy the strategy that composed this strategy function
      * @return a {@link java.util.function.Supplier} that accepts a {@link java.util.function.Supplier} with
-     * {@link com.tinkerpop.gremlin.structure.Property#key()} signature
+     * {@link org.apache.tinkerpop.gremlin.structure.Property#key()} signature
      * and returns an enhanced strategy {@link java.util.function.Supplier} with the same signature
      */
     public default <V> UnaryOperator<Supplier<String>> getPropertyKeyStrategy(final StrategyContext<StrategyProperty<V>> ctx, final GraphStrategy composingStrategy) {

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdStrategy.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdStrategy.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdStrategy.java
index d47b086..1d3379e 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdStrategy.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdStrategy.java
@@ -16,19 +16,19 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
-
-import com.tinkerpop.gremlin.process.T;
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.structure.Contains;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.util.function.TriFunction;
+package org.apache.tinkerpop.gremlin.structure.strategy;
+
+import org.apache.tinkerpop.gremlin.process.T;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.structure.Contains;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.util.function.TriFunction;
 
 import java.util.ArrayList;
 import java.util.Arrays;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdentityStrategy.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdentityStrategy.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdentityStrategy.java
index f1a0f5a..941feba 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdentityStrategy.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/IdentityStrategy.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
+package org.apache.tinkerpop.gremlin.structure.strategy;
 
-import com.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
 
 /**
  * A pass through implementation of {@link GraphStrategy} where all strategy functions are simply executed as

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/PartitionStrategy.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/ReadOnlyStrategy.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/ReadOnlyStrategy.java
index d76085d..fee22fc 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/ReadOnlyStrategy.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/ReadOnlyStrategy.java
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
-
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.util.function.TriFunction;
+package org.apache.tinkerpop.gremlin.structure.strategy;
+
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.util.function.TriFunction;
 
 import java.util.Collections;
 import java.util.Map;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SequenceStrategy.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SequenceStrategy.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SequenceStrategy.java
index 64f472f..65ffda0 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SequenceStrategy.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SequenceStrategy.java
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
+package org.apache.tinkerpop.gremlin.structure.strategy;
 
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.util.function.TriFunction;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.util.function.TriFunction;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -352,7 +352,7 @@ public final class SequenceStrategy implements GraphStrategy {
         /**
          * Provide the sequence of {@link GraphStrategy} implementations to execute.  If this value is not set,
          * then a {@code SequenceStrategy} is initialized with a single
-         * {@link com.tinkerpop.gremlin.structure.strategy.IdentityStrategy} instance.
+         * {@link org.apache.tinkerpop.gremlin.structure.strategy.IdentityStrategy} instance.
          */
         public Builder sequence(final GraphStrategy... strategies) {
             this.strategies = new ArrayList<>(Arrays.asList(strategies));

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyContext.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyEdge.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyEdge.java
index 9517498..d0fc00e 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyEdge.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyEdge.java
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
-
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.structure.util.wrapped.WrappedEdge;
-import com.tinkerpop.gremlin.util.iterator.IteratorUtils;
+package org.apache.tinkerpop.gremlin.structure.strategy;
+
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.util.wrapped.WrappedEdge;
+import org.apache.tinkerpop.gremlin.util.iterator.IteratorUtils;
 
 import java.util.Iterator;
 import java.util.NoSuchElementException;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyElement.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyElement.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyElement.java
index 46d8fed..cf742f8 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyElement.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyElement.java
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
+package org.apache.tinkerpop.gremlin.structure.strategy;
 
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
 
 /**
  * @author Stephen Mallette (http://stephen.genoprime.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyGraph.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyProperty.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyProperty.java
index 09d0c10..85b4492 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyProperty.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyProperty.java
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
-
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.structure.util.wrapped.WrappedProperty;
+package org.apache.tinkerpop.gremlin.structure.strategy;
+
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.util.wrapped.WrappedProperty;
 
 import java.util.NoSuchElementException;
 import java.util.function.Consumer;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVariables.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVariables.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVariables.java
index f492389..0e8dae7 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVariables.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVariables.java
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
+package org.apache.tinkerpop.gremlin.structure.strategy;
 
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.structure.util.wrapped.WrappedVariables;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.util.wrapped.WrappedVariables;
 
 import java.util.Map;
 import java.util.Optional;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertex.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertex.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertex.java
index 7276b10..87c1bc2 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertex.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertex.java
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
-
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.structure.util.wrapped.WrappedVertex;
-import com.tinkerpop.gremlin.util.iterator.IteratorUtils;
+package org.apache.tinkerpop.gremlin.structure.strategy;
+
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.util.wrapped.WrappedVertex;
+import org.apache.tinkerpop.gremlin.util.iterator.IteratorUtils;
 
 import java.util.Iterator;
 import java.util.NoSuchElementException;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertexProperty.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertexProperty.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertexProperty.java
index cf88a50..56e028c 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertexProperty.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyVertexProperty.java
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
-
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.structure.util.wrapped.WrappedVertexProperty;
-import com.tinkerpop.gremlin.util.iterator.IteratorUtils;
+package org.apache.tinkerpop.gremlin.structure.strategy;
+
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.util.wrapped.WrappedVertexProperty;
+import org.apache.tinkerpop.gremlin.util.iterator.IteratorUtils;
 
 import java.util.Iterator;
 import java.util.NoSuchElementException;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyWrapped.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyWrapped.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyWrapped.java
index f967385..aeb0a00 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyWrapped.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyWrapped.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
+package org.apache.tinkerpop.gremlin.structure.strategy;
 
 /**
  * A marker interface for the graph wrapper classes.  Classes that are strategy wrappers should implement this
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/PartitionStrategy.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/PartitionStrategy.java
index 7538c84..5886d3c 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/PartitionStrategy.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/PartitionStrategy.java
@@ -16,28 +16,28 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
-
-import com.tinkerpop.gremlin.process.Step;
-import com.tinkerpop.gremlin.process.Traverser;
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.process.graph.traversal.step.filter.HasStep;
-import com.tinkerpop.gremlin.process.graph.traversal.DefaultGraphTraversal;
-import com.tinkerpop.gremlin.process.graph.util.HasContainer;
-import com.tinkerpop.gremlin.process.traverser.util.DefaultTraverserGeneratorFactory;
-import com.tinkerpop.gremlin.process.traversal.util.TraversalHelper;
-import com.tinkerpop.gremlin.structure.Contains;
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.util.StreamFactory;
-import com.tinkerpop.gremlin.util.function.TriFunction;
-import com.tinkerpop.gremlin.util.iterator.IteratorUtils;
+package org.apache.tinkerpop.gremlin.structure.strategy;
+
+import org.apache.tinkerpop.gremlin.process.Step;
+import org.apache.tinkerpop.gremlin.process.Traverser;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.step.filter.HasStep;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.DefaultGraphTraversal;
+import org.apache.tinkerpop.gremlin.process.graph.util.HasContainer;
+import org.apache.tinkerpop.gremlin.process.traverser.util.DefaultTraverserGeneratorFactory;
+import org.apache.tinkerpop.gremlin.process.traversal.util.TraversalHelper;
+import org.apache.tinkerpop.gremlin.structure.Contains;
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.util.StreamFactory;
+import org.apache.tinkerpop.gremlin.util.function.TriFunction;
+import org.apache.tinkerpop.gremlin.util.iterator.IteratorUtils;
 
 import java.util.Arrays;
 import java.util.Collections;
@@ -52,8 +52,8 @@ import java.util.function.UnaryOperator;
 
 /**
  * A {@link GraphStrategy} which enables support for logical graph partitioning where the Graph can be blinded to
  * different parts of the total {@link com.tinkerpop.gremlin.structure.Graph}.  Note that the {@code partitionKey}
  * is hidden by this strategy.  Use the base {@link com.tinkerpop.gremlin.structure.Graph} to access that.
  *
  * @author Stephen Mallette (http://stephen.genoprime.com)
  * @author Joshua Shinavier (http://fortytwo.net)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/ReadOnlyStrategy.java
----------------------------------------------------------------------
@@ -52,8 +52,8 @@ import java.util.function.UnaryOperator;
 /**
  * A {@link GraphStrategy} which enables support for logical graph partitioning where the Graph can be blinded to
- * different parts of the total {@link com.tinkerpop.gremlin.structure.Graph}.  Note that the {@code partitionKey}
- * is hidden by this strategy.  Use the base {@link com.tinkerpop.gremlin.structure.Graph} to access that.
+ * different parts of the total {@link org.apache.tinkerpop.gremlin.structure.Graph}.  Note that the {@code partitionKey}
+ * is hidden by this strategy.  Use the base {@link org.apache.tinkerpop.gremlin.structure.Graph} to access that.
  *
  * @author Stephen Mallette (http://stephen.genoprime.com)
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyContext.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyContext.java
index ce78df1..05828a3 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyContext.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyContext.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
+package org.apache.tinkerpop.gremlin.structure.strategy;
 
-import com.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Graph;
 
 /**
  * The {@link StrategyContext} object is provided to the methods of {@link GraphStrategy} so that the strategy functions
@@ -46,7 +46,7 @@ public final class StrategyContext<T extends StrategyWrapped> {
     }
 
     /**
      * Gets the current {@link com.tinkerpop.gremlin.structure.strategy.StrategyGraph} instance.
      */
     public StrategyGraph getStrategyGraph() {
         return g;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyEdge.java
----------------------------------------------------------------------
@@ -46,7 +46,7 @@ public final class StrategyContext<T extends StrategyWrapped> {
 
     /**
-     * Gets the current {@link com.tinkerpop.gremlin.structure.strategy.StrategyGraph} instance.
+     * Gets the current {@link org.apache.tinkerpop.gremlin.structure.strategy.StrategyGraph} instance.
      */
     public StrategyGraph getStrategyGraph() {
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyGraph.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyGraph.java
index d80391e..6e7a8dd 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyGraph.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyGraph.java
@@ -16,18 +16,18 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
-
-import com.tinkerpop.gremlin.process.Traversal;
-import com.tinkerpop.gremlin.process.computer.GraphComputer;
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Transaction;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.structure.util.wrapped.WrappedGraph;
-import com.tinkerpop.gremlin.util.function.FunctionUtils;
+package org.apache.tinkerpop.gremlin.structure.strategy;
+
+import org.apache.tinkerpop.gremlin.process.Traversal;
+import org.apache.tinkerpop.gremlin.process.computer.GraphComputer;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Transaction;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.util.wrapped.WrappedGraph;
+import org.apache.tinkerpop.gremlin.util.function.FunctionUtils;
 import org.apache.commons.configuration.Configuration;
 
 import java.util.Iterator;
@@ -38,8 +38,8 @@ import java.util.function.UnaryOperator;
 /**
  * A wrapper class for {@link Graph} instances that host and apply a {@link GraphStrategy}.  The wrapper implements
  * {@link Graph} itself and intercepts calls made to the hosted instance and then applies the strategy.  Methods
  * that return an extension of {@link com.tinkerpop.gremlin.structure.Element} or a
  * {@link com.tinkerpop.gremlin.structure.Property} will be automatically wrapped in a {@link StrategyWrapped}
  * implementation.
  *
  * @author Stephen Mallette (http://stephen.genoprime.com)
@@ -73,7 +73,7 @@ public class StrategyGraph implements Graph, Graph.Iterators, StrategyWrapped, W
     }
 
     /**
      * Gets the {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy} for the {@link com.tinkerpop.gremlin.structure.Graph}.
      */
     public GraphStrategy getStrategy() {
         return this.strategy;
@@ -83,7 +83,7 @@ public class StrategyGraph implements Graph, Graph.Iterators, StrategyWrapped, W
      * Return a {@link GraphStrategy} function that takes the base function of the form denoted by {@code T} as
      * an argument and returns back a function with {@code T}.
      *
      * @param f    a function to execute if a {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
      * @param impl the base implementation of an operation.
      * @return a function that will be applied in the Gremlin Structure implementation
      */

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/StrategyProperty.java
----------------------------------------------------------------------
@@ -38,8 +38,8 @@ import java.util.function.UnaryOperator;
  * A wrapper class for {@link Graph} instances that host and apply a {@link GraphStrategy}.  The wrapper implements
  * {@link Graph} itself and intercepts calls made to the hosted instance and then applies the strategy.  Methods
- * that return an extension of {@link com.tinkerpop.gremlin.structure.Element} or a
- * {@link com.tinkerpop.gremlin.structure.Property} will be automatically wrapped in a {@link StrategyWrapped}
+ * that return an extension of {@link org.apache.tinkerpop.gremlin.structure.Element} or a
+ * {@link org.apache.tinkerpop.gremlin.structure.Property} will be automatically wrapped in a {@link StrategyWrapped}
  * implementation.
  *
@@ -73,7 +73,7 @@ public class StrategyGraph implements Graph, Graph.Iterators, StrategyWrapped, W
 
     /**
-     * Gets the {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy} for the {@link com.tinkerpop.gremlin.structure.Graph}.
+     * Gets the {@link org.apache.tinkerpop.gremlin.structure.strategy.GraphStrategy} for the {@link org.apache.tinkerpop.gremlin.structure.Graph}.
      */
     public GraphStrategy getStrategy() {
@@ -83,7 +83,7 @@ public class StrategyGraph implements Graph, Graph.Iterators, StrategyWrapped, W
      * an argument and returns back a function with {@code T}.
      *
-     * @param f    a function to execute if a {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
+     * @param f    a function to execute if a {@link org.apache.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
      * @param impl the base implementation of an operation.
      * @return a function that will be applied in the Gremlin Structure implementation